Project — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# Project

- /v1/projects
  - POST /v1/projects
- /v1/projects/{project_id}
  - GET /v1/projects/{project_id}
  - PUT /v1/projects/{project_id}
  - DELETE /v1/projects/{project_id}
- /v1/projects/{project_id}/close
  - POST /v1/projects/{project_id}/close
- /v1/projects/{project_id}/commit
  - POST /v1/projects/{project_id}/commit

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »